.. _github-stats_3-10-9:

GitHub statistics for 3.10.9 (Apr 23, 2026)
===========================================

GitHub statistics for 2024/12/14 (tag: v3.10.0) - 2026/04/23

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 10 issues and merged 34 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/107?closed=1>`__

The following 37 authors contributed 519 commits.

* Aasma Gupta
* Aman Srivastava
* Antony Lee
* beelauuu
* Ben Root
* Christine P. Chai
* David Stansby
* dependabot[bot]
* Elliott Sales de Andrade
* G.D. McBain
* Greg Lucas
* hannah
* hu-xiaonan
* Ian Thomas
* Inês Cachola
* Jody Klymak
* Jouni K. Seppänen
* Khushi_29
* Kyle Sunden
* Lumberbot (aka Jack)
* m-sahare
* N R Navaneet
* Nathan G. Wiseman
* Oscar Gustafsson
* Praful Gulani
* Qian Zhang
* Raphael Erik Hviding
* Raphael Quast
* Roman
* Ruth Comer
* saikarna913
* Scott Shambaugh
* Steve Berardi
* Thomas A Caswell
* Tim Hoffmann
* Trygve Magnus Ræder
* Vikash Kumar

GitHub issues and pull requests:

Pull Requests (34):

* :ghpull:`31556`: FIX: Inverted PyErr_Occurred check in enum type caster (_enums.h)
* :ghpull:`31078`: Backport PR #31075 on branch v3.10.x (Fix remove method for figure title and xy-labels)
* :ghpull:`31280`: Backport PR #31278 on branch v3.10.x (Fix ``clabel`` manual argument not accepting unit-typed coordinates)
* :ghpull:`31520`: Backport PR #31020 on branch v3.10.x (DOC: Fix doc builds with Sphinx 9)
* :ghpull:`31511`: Backport PR #31504 on branch v3.10.x (Re-order variants to prioritize narrower types)
* :ghpull:`31504`: Re-order variants to prioritize narrower types
* :ghpull:`31445`: Backport PR #31437: mathtext: Fix type inconsistency with fontmaps
* :ghpull:`31437`: mathtext: Fix type inconsistency with fontmaps
* :ghpull:`31411`: Backport PR #31323 on branch v3.10.x (FIX: Prevent crash when removing a subfigure containing subplots)
* :ghpull:`31421`: Backport PR #31420 on branch v3.10.x (Fix outdated Savannah URL for freetype download)
* :ghpull:`31420`: Fix outdated Savannah URL for freetype download
* :ghpull:`31418`: Backport PR #31401: BLD: Temporarily pin setuptools-scm<10
* :ghpull:`31323`: FIX: Prevent crash when removing a subfigure containing subplots
* :ghpull:`31401`: BLD: Temporarily pin setuptools-scm<10
* :ghpull:`31278`: Fix ``clabel`` manual argument not accepting unit-typed coordinates
* :ghpull:`31154`: Backport PR #31153 on branch v3.10.x (TST: Use correct method of clearing mock objects)
* :ghpull:`31153`: TST: Use correct method of clearing mock objects
* :ghpull:`31075`: Fix remove method for figure title and xy-labels
* :ghpull:`31036`: Backport PR #31035 on branch v3.10.x (DOCS: Fix typo in time array step size comment)
* :ghpull:`30986`: Backport PR #30985 on branch v3.10.x (MNT: do not assign a numpy array shape)
* :ghpull:`30985`: MNT: do not assign a numpy array shape
* :ghpull:`30971`: Backport PR #30969 on branch v3.10.x (DOC: Simplify barh() example)
* :ghpull:`30965`: Backport PR #30952 on branch v3.10.x (DOC: Tutorial on API shortcuts)
* :ghpull:`30964`: Backport PR #30960 on branch v3.10.x (SVG backend - handle font weight as integer)
* :ghpull:`30960`: SVG backend - handle font weight as integer
* :ghpull:`30924`: Backport PR #30910 on branch v3.10.x (DOC: Improve writer parameter docs of Animation.save())
* :ghpull:`30870`: Backport PR #30869 on branch v3.10.x (FIX: Accept array for zdir)
* :ghpull:`30869`: FIX: Accept array for zdir
* :ghpull:`30860`: Backport PR #30858 on branch v3.10.x (DOC: reinstate "codex" search term)
* :ghpull:`30818`: Backport PR #30817 on branch v3.10.x (Update sphinx-gallery header patch)
* :ghpull:`30801`: Backport PR #30763 on branch v3.10.x (DOC: Add example how to align tick labels)
* :ghpull:`30791`: Backport PR #30788 on branch v3.10.8-doc (Fix typo in key-mapping for "f11")
* :ghpull:`30790`: Backport PR #30788 on branch v3.10.x (Fix typo in key-mapping for "f11")
* :ghpull:`30788`: Fix typo in key-mapping for "f11"

Issues (10):

* :ghissue:`31495`: Unavoidable warnings with pybind11 main branch
* :ghissue:`31433`: [MNT]: Mypy error
* :ghissue:`31340`: [Bug]: outdated savannah URL in subprojects/freetype-2.6.1.wrap
* :ghissue:`31319`: [Bug]: Crash when removing a subfigure with a subplot in a figure
* :ghissue:`27525`: [Bug]: clabel manual argument does not accept units
* :ghissue:`31112`: [TST] Upcoming dependency test failures
* :ghissue:`31073`: [Bug]: Crash when Removing Suptitle in a Figure with Constrained Layout
* :ghissue:`30981`: [TST] Upcoming dependency test failures
* :ghissue:`30868`: [Bug]: Axe3D text() method does not allow zdir=numpy.array(...)
* :ghissue:`21566`: [ENH]: set_horizontalalignment("right") on Y axis labels when yaxis.ticks_right() is used.
